goog.workspace.drive

Clojure wrapper for the Google Drive API (v3).

Provides idiomatic Clojure functions for managing files, permissions, comments, replies, revisions, and changes in Google Drive.

Auth: use csl/scoped-delegated-credentials or csl/user-credentials with the appropriate scope:

  • DriveScopes/DRIVE (full access)
  • DriveScopes/DRIVE_FILE (files created/opened by the app)
  • DriveScopes/DRIVE_READONLY (read-only access)
  • DriveScopes/DRIVE_METADATA (metadata only)
  • DriveScopes/DRIVE_METADATA_READONLY (metadata read-only)
  • DriveScopes/DRIVE_APPS_READONLY (list-apps only — not covered by any other Drive scope; carved out separately by Google)

All list functions return {:data [...] :next-page-token "..."}; the caller is responsible for pagination by passing :page-token from one call to the next. :next-page-token is absent when there are no further pages.

All functions return {:data ...} on success or {:error ...} on failure.

Clojure wrapper for the Google Drive API (v3).

Provides idiomatic Clojure functions for managing files, permissions,
comments, replies, revisions, and changes in Google Drive.

Auth: use csl/scoped-delegated-credentials or csl/user-credentials with
the appropriate scope:
- DriveScopes/DRIVE                   (full access)
- DriveScopes/DRIVE_FILE              (files created/opened by the app)
- DriveScopes/DRIVE_READONLY          (read-only access)
- DriveScopes/DRIVE_METADATA          (metadata only)
- DriveScopes/DRIVE_METADATA_READONLY (metadata read-only)
- DriveScopes/DRIVE_APPS_READONLY     (list-apps only — not covered by any
                                       other Drive scope; carved out separately
                                       by Google)

All list functions return {:data [...] :next-page-token "..."}; the caller
is responsible for pagination by passing :page-token from one call to the next.
:next-page-token is absent when there are no further pages.

All functions return {:data ...} on success or {:error ...} on failure.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries